@@ -75,16 +75,23 @@ kolab_util_calendar_store (ECalComponent *ecalcomp,
                            GCancellable *cancellable,
                            GError **error);
 
-#if 0 /* FIXME old */
-ECalBackendSyncStatus
+gboolean
 kolab_util_calendar_extract (icalcomponent *icalcomp,
                              ECalSourceType source_type,
                              ECalComponent **ecalcomp,
-                             ECalComponent **tzcomp);
+                             ECalComponent **tzcomp,
+                             GError **error);
 
+#if 0
 ECalBackendSyncStatus kolab_util_calendar_map_error (GError *error);
 #endif
 
+void
+kolab_util_calendar_err_to_edb_err (GError **e_err,
+                                    const GError *k_err,
+                                    const gchar *func,
+                                    guint line);
+
 /*----------------------------------------------------------------------------*/
 
 #endif /* _KOLAB_UTIL_CALENDAR_H_ */
