@@ -167,7 +167,7 @@ imapx_extd_folder_append_message_sync (CamelFolder *self,
 	g_assert (CAMEL_IS_IMAPX_EXTD_FOLDER (self));
 	g_assert (CAMEL_IS_MIME_MESSAGE (message));
 	/* info may be NULL */ /* FIXME correct? */
-	g_assert (*appended_uid == NULL);
+	/* FIXME what can we assert for **appended_uid? */
 	/* cancellable may be NULL */
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
@@ -311,17 +311,14 @@ static guint64
 imapx_extd_folder_get_uidvalidity (CamelIMAPXExtdFolder *self,
                                    GError **err)
 {
-	guint64 uidvalidity = 0;
+	CamelIMAPXFolder *ifolder = NULL;
 
 	g_assert (CAMEL_IS_IMAPX_EXTD_FOLDER (self));
 	g_return_val_if_fail (err == NULL || *err == NULL, 0);
 
-	/* FIXME implement me */
-	g_error ("%s: FIXME implement me", __func__);
+	ifolder = CAMEL_IMAPX_FOLDER (self);
 
-	/* TODO read the uidvalidity value from parent object */
-
-	return uidvalidity;
+	return ifolder->uidvalidity_on_server;
 }
 /*----------------------------------------------------------------------------*/
 /* class init */
