@@ -81,11 +81,11 @@ kolab_folder_permissions_ui_edit_dialog_cb (KolabFolderPermUIData *uidata)
 	g_assert (uidata->widgets != NULL);
 
 	dialog = gtk_dialog_new_with_buttons (_("Edit Kolab Folder Permissions..."),
-		                             NULL, /* parent */
-		                             GTK_DIALOG_DESTROY_WITH_PARENT|GTK_DIALOG_MODAL,
-		                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-		                             GTK_STOCK_OK, GTK_RESPONSE_OK,
-		                             NULL);
+	                                      NULL, /* parent */
+	                                      GTK_DIALOG_DESTROY_WITH_PARENT|GTK_DIALOG_MODAL,
+	                                      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+	                                      GTK_STOCK_OK, GTK_RESPONSE_OK,
+	                                      NULL);
 
 	content = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 	gtk_container_set_border_width (GTK_CONTAINER (content), 6);
@@ -220,9 +220,10 @@ kolab_folder_permissions_ui_create_tree_view (KolabFolderPermUIData *uidata)
 
 	selection = gtk_tree_view_get_selection (tree_view);
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
-	/* FIXME connect signal to callback
+#if 0
+	/* FIXME connect signal to callback */
 	g_signal_connect (selection, "changed", G_CALLBACK (folder_permissions_tree_selection_changed_cb), widgets);
-	*/
+#endif
 	gtk_tree_view_set_headers_visible (tree_view, TRUE);
 	gtk_tree_view_set_headers_clickable (tree_view, FALSE);
 	gtk_tree_view_set_fixed_height_mode (tree_view, TRUE);
