@@ -1384,10 +1384,7 @@ kolab_mail_info_db_update_folder_summary (KolabMailInfoDb *self,
 	priv = KOLAB_MAIL_INFO_DB_PRIVATE (self);
 
 	g_assert (priv->is_up == TRUE);
-#if 0
-	foldername = kolab_folder_summary_get_char_field (summary,
-	                                                  KOLAB_FOLDER_SUMMARY_CHAR_FIELD_FOLDERNAME);
-#endif
+
 	/* TODO check what needs to be done here */
 
 	/* TODO Take care of re-adding folders which have been marked
@@ -1645,10 +1642,7 @@ kolab_mail_info_db_update_record (KolabMailInfoDb *self,
 	g_assert (priv->is_up == TRUE);
 
 	g_assert (kolab_mail_summary_check (record->summary));
-#if 0
-	uid = kolab_mail_summary_get_char_field (record->summary,
-	                                         KOLAB_MAIL_SUMMARY_CHAR_FIELD_KOLAB_UID);
-#endif
+
 	/* check folder existence */
 	folder_summary = kolab_mail_info_db_query_folder_summary (self,
 	                                                          foldername,
