@@ -25,8 +25,12 @@
 
 /*----------------------------------------------------------------------------*/
 
+#include <config.h>
+
 #include <time.h>
 
+#include <glib/gi18n-lib.h>
+
 #include <libecal/e-cal-time-util.h>
 
 #include <libekolabutil/kolab-util-glib.h>
@@ -208,8 +212,8 @@ kolab_mail_synchronizer_get_foldertype (KolabMailSynchronizer *self,
 		g_set_error (&tmp_err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_NOTFOUND,
-		             "%s: Folder found neither in InfoDb (%s) nor in ImapClient (%s)",
-		             __func__, info_fn, imap_fn);
+		             _("Folder not found, neither in internal database as '%s', nor on the server as '%s'"),
+		             info_fn, imap_fn);
 		goto skip;
 	}
 
@@ -444,8 +448,7 @@ kolab_mail_synchronizer_folders_update_summary (KolabMailSynchronizer *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_INTERNAL,
-		             "%s: no foldername from either InfoDb/ImapClient/SideCache",
-		             __func__);
+		             _("Internal inconsistency detected: Could not get a folder name, no info from internal database, write cache, or the IMAP cache"));
 		return FALSE;
 	}
 
@@ -486,8 +489,8 @@ kolab_mail_synchronizer_folders_update_summary (KolabMailSynchronizer *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_DATATYPE_INTERNAL,
-		             "%s: Folder type (%i) does not map to any folder context",
-		             __func__, folder_type);
+		             _("Internal inconsistency detected, Folder type %i does not map to any known folder context"),
+		             folder_type);
 		return FALSE;
 	}
 
@@ -1163,8 +1166,8 @@ kolab_mail_synchronizer_uids_update_infodb (KolabMailSynchronizer *self,
 			g_set_error (err,
 			             KOLAB_BACKEND_ERROR,
 			             KOLAB_BACKEND_ERROR_INFODB_NOFOLDER,
-			             "%s: Folder does not exist in InfoDb: %s",
-			             __func__, foldername);
+			             _("Folder does not exist in internal database: '%s'"),
+			             foldername);
 			return FALSE;
 		}
 
@@ -1867,8 +1870,7 @@ kolab_mail_synchronizer_transaction_prepare (KolabMailSynchronizer *self,
 		g_set_error (&tmp_err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_DATATYPE_INTERNAL,
-		             "%s: UID not set on KolabMailHandle",
-		             __func__);
+		             _("Internal inconsistency detected: PIM Object handle has no Kolab UID set"));
 		goto cleanup;
 	}
 	kmh_summary = kolab_mail_handle_get_summary (kmailhandle);
@@ -2494,8 +2496,8 @@ kolab_mail_synchronizer_info_sync (KolabMailSynchronizer *self,
 			g_set_error (err,
 			             KOLAB_BACKEND_ERROR,
 			             KOLAB_BACKEND_ERROR_INFODB_GENERIC,
-			             "%s: %s (%s)",
-			             __func__, tmp_err_2->message, tmp_err->message);
+			             "%s (%s)",
+			             tmp_err_2->message, tmp_err->message);
 			g_error_free (tmp_err);
 			g_error_free (tmp_err_2);
 		} else {
@@ -2548,8 +2550,8 @@ kolab_mail_synchronizer_info_sync (KolabMailSynchronizer *self,
 			g_set_error (err,
 			             KOLAB_BACKEND_ERROR,
 			             KOLAB_BACKEND_ERROR_INFODB_GENERIC,
-			             "%s: %s (%s)",
-			             __func__, tmp_err_2->message, tmp_err->message);
+			             "%s (%s)",
+			             tmp_err_2->message, tmp_err->message);
 			g_error_free (tmp_err);
 			g_error_free (tmp_err_2);
 		} else {
