@@ -31,16 +31,22 @@
 /*----------------------------------------------------------------------------*/
 
 #include <glib.h>
-
-#include "kolab-settings-handler.h"
-#include "kolab-types.h"
+#include <gio/gio.h>
 
 #include <libebook/e-contact.h>
 #include <libecal/e-cal-component.h>
 #include <libedataserver/e-source.h>
 
+#include <libekolabutil/camel-system-headers.h>
 #include <libekolabutil/kolab-util-sqlite.h>
 
+#include "kolab-settings-handler.h"
+#include "kolab-types.h"
+#include "kolab-backend-types.h"
+
+/*----------------------------------------------------------------------------*/
+
+struct _KolabMailAccess;
 
 /*----------------------------------------------------------------------------*/
 /* GError for libekolabbackend */
@@ -87,6 +93,21 @@ gboolean kolab_util_backend_sqlite_db_new_open (KolabUtilSqliteDb **kdb, KolabSe
 const gchar* kolab_util_backend_get_sync_strategy_desc (KolabSyncStrategyID id);
 const gchar* kolab_util_backend_get_tls_variant_desc (KolabTLSVariantID id);
 
+CamelURL* kolab_util_backend_camel_url_new_from_settings (KolabSettingsHandler *ksettings, GError **err);
+gchar* kolab_util_backend_account_uid_new_from_settings (KolabSettingsHandler *ksettings, GError **err);
+
+KolabMailAccessOpmodeID
+kolab_util_backend_deploy_mode_by_koma (struct _KolabMailAccess *koma,
+                                        KolabMailAccessOpmodeID koma_mode,
+                                        GCancellable *cancellable,
+                                        GError **error);
+
+gboolean
+kolab_util_backend_deploy_mode_by_backend (struct _KolabMailAccess *koma,
+                                           gboolean online,
+                                           GCancellable *cancellable,
+                                           GError **error);
+
 /*----------------------------------------------------------------------------*/
 
 #endif /* _KOLAB_UTIL_BACKEND_H_ */
